[![Build Status](https://app.travis-ci.com/mkrum/chessplotlib.svg?branch=main)](https://app.travis-ci.com/mkrum/chessplotlib)
[![PyPI
version](https://badge.fury.io/py/chessplotlib.svg)](https://badge.fury.io/py/chessplotlib)
[![Documentation
Status](https://readthedocs.org/projects/chessplotlib/badge/?version=latest)](https://chessplotlib.readthedocs.io/en/latest/?badge=latest)
# ♚ chessplotlib
Chess visualizations with matplotlib. 

[Docs are available here.](https://chessplotlib.readthedocs.io/en/latest/about.html)

![](examples/starting_board.png)

